==> jc-1.4.0.tar.gz: java/awt/JobAttributes__24DefaultSelectionType.h <==
// public final class java.awt.JobAttributes$DefaultSelectionType

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class 8a016004463e54cc java_awt_JobAttributes__24DefaultSelectionType
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_AttributeValue

#include "java/awt/AttributeValue.h"

#ifndef _JC_java_awt_JobAttributes__24DefaultSelectionType_H_
#define _JC_java_awt_JobAttributes__24DefaultSelectionType_H_

// Forward structure declarations
struct _jc_java_awt_JobAttributes__24DefaultSelectionType$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_JobAttributes__24DefaultSelectionType$sub_refs	_jc_java_awt_JobAttributes__24DefaultSelectionType$sub_refs;
typedef struct _jc_java_awt_JobAttributes__24DefaultSelectionType$sub_nonrefs	_jc_java_awt_JobAttributes__24DefaultSelectionType$sub_nonrefs;
typedef struct _jc_java_awt_JobAttributes__24DefaultSelectionType$refs	_jc_java_awt_JobAttributes__24DefaultSelectionType$refs;
typedef struct _jc_java_awt_JobAttributes__24DefaultSelectionType$nonrefs	_jc_java_awt_JobAttributes__24DefaultSelectionType$nonrefs;
typedef struct _jc_java_awt_JobAttributes__24DefaultSelectionType$object	_jc_java_awt_JobAttributes__24DefaultSelectionType$object;

typedef struct _jc_java_awt_JobAttributes__24DefaultSelectionType$fields_struct	_jc_java_awt_JobAttributes__24DefaultSelectionType$fields_struct;
typedef const struct _jc_java_awt_JobAttributes__24DefaultSelectionType$vmethods	_jc_java_awt_JobAttributes__24DefaultSelectionType$vmethods;
typedef const struct _jc_java_awt_JobAttributes__24DefaultSelectionType$vtable	_jc_java_awt_JobAttributes__24DefaultSelectionType$vtable;
typedef const struct _jc_java_awt_JobAttributes__24DefaultSelectionType$vtype	_jc_java_awt_JobAttributes__24DefaultSelectionType$vtype;

// Class fields structure
struct _jc_java_awt_JobAttributes__24DefaultSelectionType$fields_struct {
	struct _jc_java_awt_JobAttributes__24DefaultSelectionType$object	*ALL;
	_jc_object_array	*NAMES;
	struct _jc_java_awt_JobAttributes__24DefaultSelectionType$object	*RANGE;
	struct _jc_java_awt_JobAttributes__24DefaultSelectionType$object	*SELECTION;
};
extern _jc_java_awt_JobAttributes__24DefaultSelectionType$fields_struct _jc_java_awt_JobAttributes__24DefaultSelectionType$class_fields;

// Constructors
extern void _jc_java_awt_JobAttributes__24DefaultSelectionType$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_JobAttributes__24DefaultSelectionType$object *, jint);

// Static methods
extern void _jc_java_awt_JobAttributes__24DefaultSelectionType$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_awt_JobAttributes__24DefaultSelectionType$vmethods {
};

// Vtable
struct _jc_java_awt_JobAttributes__24DefaultSelectionType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AttributeValue$vmethods	java_awt_AttributeValue;
	_jc_java_awt_JobAttributes__24DefaultSelectionType$vmethods	java_awt_JobAttributes__24DefaultSelectionType;
};

// Vtype
struct _jc_java_awt_JobAttributes__24DefaultSelectionType$vtype {
	_jc_type			type;
	_jc_java_awt_JobAttributes__24DefaultSelectionType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_JobAttributes__24DefaultSelectionType$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_JobAttributes__24DefaultSelectionType$refs {
    _jc_java_awt_JobAttributes__24DefaultSelectionType$sub_refs	java_awt_JobAttributes__24DefaultSelectionType;
    _jc_java_awt_AttributeValue$sub_refs	java_awt_AttributeValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_JobAttributes__24DefaultSelectionType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_JobAttributes__24DefaultSelectionType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AttributeValue$sub_nonrefs	java_awt_AttributeValue;
    _jc_java_awt_JobAttributes__24DefaultSelectionType$sub_nonrefs	java_awt_JobAttributes__24DefaultSelectionType;
};

// Object instance structure
struct _jc_java_awt_JobAttributes__24DefaultSelectionType$object {
	_jc_java_awt_JobAttributes__24DefaultSelectionType$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_JobAttributes__24DefaultSelectionType$vtype	*vtype;
	_jc_java_awt_JobAttributes__24DefaultSelectionType$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_JobAttributes__24DefaultSelectionType$vtype _jc_java_awt_JobAttributes__24DefaultSelectionType$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_JobAttributes__24DefaultSelectionType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_JobAttributes__24DefaultSelectionType$class_object;

#endif	/* _JC_java_awt_JobAttributes__24DefaultSelectionType_H_ */

==> jc-1.4.6.tar.gz: java/awt/JobAttributes__24DefaultSelectionType.h <==
// public final class java.awt.JobAttributes$DefaultSelectionType

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class 8a016004463e54cc java_awt_JobAttributes__24DefaultSelectionType
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_AttributeValue

#include "java/awt/AttributeValue.h"

#ifndef _JC_java_awt_JobAttributes__24DefaultSelectionType_H_
#define _JC_java_awt_JobAttributes__24DefaultSelectionType_H_

// Forward structure declarations
struct _jc_java_awt_JobAttributes__24DefaultSelectionType$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_JobAttributes__24DefaultSelectionType$sub_refs	_jc_java_awt_JobAttributes__24DefaultSelectionType$sub_refs;
typedef struct _jc_java_awt_JobAttributes__24DefaultSelectionType$sub_nonrefs	_jc_java_awt_JobAttributes__24DefaultSelectionType$sub_nonrefs;
typedef struct _jc_java_awt_JobAttributes__24DefaultSelectionType$refs	_jc_java_awt_JobAttributes__24DefaultSelectionType$refs;
typedef struct _jc_java_awt_JobAttributes__24DefaultSelectionType$nonrefs	_jc_java_awt_JobAttributes__24DefaultSelectionType$nonrefs;
typedef struct _jc_java_awt_JobAttributes__24DefaultSelectionType$object	_jc_java_awt_JobAttributes__24DefaultSelectionType$object;

typedef struct _jc_java_awt_JobAttributes__24DefaultSelectionType$fields_struct	_jc_java_awt_JobAttributes__24DefaultSelectionType$fields_struct;
typedef const struct _jc_java_awt_JobAttributes__24DefaultSelectionType$vmethods	_jc_java_awt_JobAttributes__24DefaultSelectionType$vmethods;
typedef const struct _jc_java_awt_JobAttributes__24DefaultSelectionType$vtable	_jc_java_awt_JobAttributes__24DefaultSelectionType$vtable;
typedef const struct _jc_java_awt_JobAttributes__24DefaultSelectionType$vtype	_jc_java_awt_JobAttributes__24DefaultSelectionType$vtype;

// Class fields structure
struct _jc_java_awt_JobAttributes__24DefaultSelectionType$fields_struct {
	struct _jc_java_awt_JobAttributes__24DefaultSelectionType$object	*ALL;
	_jc_object_array	*NAMES;
	struct _jc_java_awt_JobAttributes__24DefaultSelectionType$object	*RANGE;
	struct _jc_java_awt_JobAttributes__24DefaultSelectionType$object	*SELECTION;
};
extern _jc_java_awt_JobAttributes__24DefaultSelectionType$fields_struct _jc_java_awt_JobAttributes__24DefaultSelectionType$class_fields;

// Constructors
extern void _jc_java_awt_JobAttributes__24DefaultSelectionType$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_JobAttributes__24DefaultSelectionType$object *, jint) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_awt_JobAttributes__24DefaultSelectionType$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_JobAttributes__24DefaultSelectionType$vmethods {
};

// Vtable
struct _jc_java_awt_JobAttributes__24DefaultSelectionType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AttributeValue$vmethods	java_awt_AttributeValue;
	_jc_java_awt_JobAttributes__24DefaultSelectionType$vmethods	java_awt_JobAttributes__24DefaultSelectionType;
};

// Vtype
struct _jc_java_awt_JobAttributes__24DefaultSelectionType$vtype {
	_jc_type			type;
	_jc_java_awt_JobAttributes__24DefaultSelectionType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_JobAttributes__24DefaultSelectionType$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_JobAttributes__24DefaultSelectionType$refs {
    _jc_java_awt_JobAttributes__24DefaultSelectionType$sub_refs	java_awt_JobAttributes__24DefaultSelectionType;
    _jc_java_awt_AttributeValue$sub_refs	java_awt_AttributeValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_JobAttributes__24DefaultSelectionType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_JobAttributes__24DefaultSelectionType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AttributeValue$sub_nonrefs	java_awt_AttributeValue;
    _jc_java_awt_JobAttributes__24DefaultSelectionType$sub_nonrefs	java_awt_JobAttributes__24DefaultSelectionType;
};

// Object instance structure
struct _jc_java_awt_JobAttributes__24DefaultSelectionType$object {
	_jc_java_awt_JobAttributes__24DefaultSelectionType$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_JobAttributes__24DefaultSelectionType$vtype	*vtype;
	_jc_java_awt_JobAttributes__24DefaultSelectionType$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_JobAttributes__24DefaultSelectionType$vtype _jc_java_awt_JobAttributes__24DefaultSelectionType$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_JobAttributes__24DefaultSelectionType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_JobAttributes__24DefaultSelectionType$class_object;

#endif	/* _JC_java_awt_JobAttributes__24DefaultSelectionType_H_ */
